# rayter-generator

[![Build Status](https://github.com/rayter-org/rayter-generator/workflows/Tests/badge.svg)](https://github.com/rayter-org/rayter-generator/actions?query=workflow%3ATests)

A static site generator for game ranking leagues.
